package ru.volgait2015.strepetov.portknocking;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.Socket;
import java.net.UnknownHostException;
import java.util.logging.Logger;

/**
 * Represents the implementation of port-knocking client
 */
public class Client {

    private static final String SERVER_HOST_NAME = "localhost";

    private static final int SERVER_START_PORT = 45000;

    private static final Logger log = Logger.getLogger(Client.class.getSimpleName());

    public static void main(String[] args) throws IOException {

        String messageFromServer = connectToServer(SERVER_START_PORT);

        while (!messageFromServer.startsWith("Hello")) {
            messageFromServer = connectToServer(Integer.parseInt(messageFromServer));
        }
        log.info("Server sent final message:\""+messageFromServer+"\"");
    }

    /**
     * Connects to the server and returns message from it
     * @param port Port of the server
     * @return message from Server
     * @throws IOException
     */
    private static String connectToServer(int port) throws IOException {
        Socket socket = null;
        PrintWriter out = null;
        BufferedReader in = null;

        try {
            log.info("Client is trying to connect to "+SERVER_HOST_NAME+":"+port);
            socket = new Socket(SERVER_HOST_NAME, port);
            out = new PrintWriter(socket.getOutputStream(), true);
            in = new BufferedReader(new InputStreamReader(
                    socket.getInputStream()));
        } catch (UnknownHostException e) {
            log.severe("Don't know about host: " + SERVER_HOST_NAME);
            System.exit(1);
        } catch (IOException e) {
            log.severe("Couldn't get I/O for "
                    + "the connection to: " + SERVER_HOST_NAME);
            System.exit(1);
        }
        log.info("Connection was successful");

        String messageFromPort = in.readLine();

        log.info("Message from server:\"" + messageFromPort+"\"");


        out.close();
        in.close();
        socket.close();

        return messageFromPort;
    }
}
